Output

Trait Output 

pub trait Output:
    DynClone
    + Debug
    + Sync {
    // Required method
    fn write_observations(
        &self,
        observations: &[LocalObservation],
        observatory_name: &str,
        time: i128,
        output_path_root: &Path,
    ) -> Result<(), Error>;

    // Provided method
    fn flush(&self) -> Result<(), Error> { ... }
}
The trait for structs that output to a file. It may be made more general in future to better accommodate non-file outputs e.g. console loggers, or outputs to screen or streams

Required Methods

fn write_observations( &self, observations: &[LocalObservation], observatory_name: &str, time: i128, output_path_root: &Path, ) -> Result<(), Error>

Errors

implementations may panic if there is an error in the filesystem e.g. writing is not allowed for a user in a specific directory, or one or more of the directories are files that have already been created

Provided Methods

fn flush(&self) -> Result<(), Error>

Errors

implementations may panif if there is an error in the filesystem e.g. the user is missing permissions, a directory in the path is a file.

Implementors

Source

impl Output for Logger

Source

impl<T> Output for Svg<T>
where T: Projection + Clone + Debug + Sync,