pub fn make_toy_example(seed: u128) -> (Arc, Arc)Expand description
Generates an example crate::body::Body tree from a seed, at the moment this will only
generate a tree with five ancestors of the observing body, the observing body, nine
children of the observing body, and 9 children of those children (81 descendants in total)
Returns
([crate::body::Arc], [crate::body::Arc]) where the first Arc is the root body, and must
be kept alive to keep all the ancestors of the intended observing body in scope; and the second Arc is intended to be the observing body.